<?php

/**
 * Plugin Name:       Advanced Donation
 * Plugin URI:        https://woocommerce.com/products/addify-advanced-donation/
 * Description:       Run donation campaigns on your WooCommerce store to raise funds for non-profit organizations, social causes and more.
 * Version:           1.1.1
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path:       /languages
 * Text Domain:       af_donation
 * WC requires at least: 3.0.9
 * WC tested up to: 8.*.*
 * Woo: 18734001531162:883b6b5a7a05e0ab6e65547ed3f8b339
 *
 * @package wc-donation
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}


if ( !class_exists('AF_Wc_Donation_Main') ) {

	/**
	 * Main class of Plugin
	 */
	class AF_Wc_Donation_Main {

		/**
		 * Constructor of class.
		 *
		 * @return void
		 */
		public function __construct() {

			$this->af_wcd_global_constents_vars();

			register_activation_hook(__FILE__, array( $this, 'af_donat_activation_changes' ));

			add_action('wp_loaded', array( $this, 'afwcd_load_text_domain' ));

			add_action('wp_loaded', array( $this, 'afwcd_create_post' ));

			add_action('woocommerce_add_to_cart_validation', array( $this, 'add_to_cart_validation' ), 100, 3 );

			add_action('wp_ajax_af_donat_chart_update_date', array( $this, 'af_donat_chart_update' ));

			add_action('wp_ajax_nopriv_af_donat_chart_update_date', array( $this, 'af_donat_chart_update' ));

			add_action('wp_ajax_af_donat_add_to_card', array( $this, 'af_donat_add_to_card' ), 100);

			add_action('wp_ajax_nopriv_af_donat_add_to_card', array( $this, 'af_donat_add_to_card' ), 100);

			add_action('wp_ajax_af_donat_add_fee_in_cart', array( $this, 'af_donat_add_fee_in_cart' ));

			add_action('wp_ajax_nopriv_af_donat_add_fee_in_cart', array( $this, 'af_donat_add_fee_in_cart' ));

			add_action('wp_ajax_af_donat_show_amt_optn_chkt', array( $this, 'af_donat_show_amt_optn_chkt' ));

			add_action('wp_ajax_nopriv_af_donat_show_amt_optn_chkt', array( $this, 'af_donat_show_amt_optn_chkt' ));

			add_action('wp_ajax_af_donation_btn_chkout', array( $this, 'af_donation_btn_chkout' ));

			add_action('wp_ajax_nopriv_af_donation_btn_chkout', array( $this, 'af_donation_btn_chkout' ));

			add_filter('woocommerce_email_classes', array( $this, 'af_add_email_classes' ), 90, 1);

			add_action('wp_trash_post', array( $this, 'af_del_rule_del_prod' ), 10);

			add_action( 'woocommerce_cart_item_removed', array( $this, 'remove_fee' ), 30, 2 );

			if (is_admin()) {

				include_once AFWCD_PLUGIN_DIR . '/includes/class-af-wc-donation-admin.php';
			} else {

				include_once AFWCD_PLUGIN_DIR . '/includes/class-af-wc-donation-front.php';
			}

			add_action('init', array( $this, 'close_donations_automatically' ) );

			//HOPS compatibility
			add_action('before_woocommerce_init', array( $this, 'afwcd_HOPS_Compatibility' ));

			add_action( 'plugins_loaded', array( $this, 'afwcd_checks' ) ); 
		}

		public function afwcd_checks() {

			// Check the installation of WooCommerce module if it is not a multi site.
			if ( ! is_multisite() ) {
				if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
					
					add_action( 'admin_notices', array( $this, 'afwcd_check_wocommerce' ));
				}
			}
		}

		public function afccm_check_wocommerce() {


			// Deactivate the plugin.
			deactivate_plugins(__FILE__);

			$afpvu_woo_check = '<div id="message" class="error">
				<p><strong>' . __('Advanced Donation plugin is inactive.', 'af_donation') . '</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> ' . __('must be active for this plugin to work. Please install &amp; activate WooCommerce.', 'af_donation') . ' »</p></div>';
			echo wp_kses_post($afpvu_woo_check);
		}

		public function afwcd_HOPS_Compatibility() {

			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}

		public function remove_fee( $cart_item_key, $cart_item ) {

			if ( wc()->cart->is_empty() ) {
				wc()->session->set('af_done_fee_in_cart', '');
			}
		}

		public function add_to_cart_validation( $validate, $product_id, $quantity ) {
			$rule_id      = get_post_meta($product_id, 'af_donation_product_rule', true);
			$closing_date = get_post_meta($rule_id, 'af_donatio_close_date', true);

			if ( !empty( $closing_date ) && strtotime( $closing_date ) < time() ) {
				wc_add_notice( __('You cannot donate for this campaign. It has been closed.', 'af_donation'), 'error');
				return false;
			}

			return $validate;
		}

		/**
		 * Load Text domain.
		 */
		public function af_check_if_no_camp() {

			$check_empt          = 'false';
			$af_wc_donat_rule_id = get_posts(
				array(
					'numberposts' => -1,
					'post_status' => 'publish',
					'post_type'   => 'af_wc_donat',
					'orderby'     => 'ids',
					'order'       => 'DSC',
					'fields'      => 'ids',
				)
			);

			if (empty($af_wc_donat_rule_id)) {

				$af_donate_cart_data = '';
				?>
				<script type="text/javascript">
				var af_donate_cart_data = <?php echo wp_json_encode($af_wc_donat_rule_id); ?>;
				</script>
				<?php

			}
		}

		public function af_del_rule_del_prod( $post_id ) {

			if (!empty(get_post_meta($post_id, 'af_rule_as_prod', true))) {

				wp_delete_post(get_post_meta($post_id, 'af_rule_as_prod', true));
			}
		}

		public function afwcd_load_text_domain() {
			if (function_exists('load_plugin_textdomain')) {
				load_plugin_textdomain('af_donation', false, dirname(plugin_basename(__FILE__)) . '/languages/');
			}
		}

		public function af_donat_activation_changes() {
			if (empty(get_option('af_donat_notify_msg_editor_id'))) {
				update_option('af_donat_notify_msg_editor_id', 'Donation against {campaign_name} successfully added to cart.');
			}
		}

		public function af_add_email_classes( $emails ) {

			include_once AFWCD_PLUGIN_DIR . 'template/email/class-af-donat-receive-email.php';
			include_once AFWCD_PLUGIN_DIR . 'template/email/class-af-donat-thankyou-email.php';

			$emails['af_donation_recieve_mail'] = new Af_Donat_Receive_Email();
			$emails['af_donation_thanks_mail']  = new Af_thank_for_donation();

			return $emails;
		}

		public function af_donat_camp_goal_setting_optn( $af_donat_rule_ ) {

			$af_donat_enable_goal = get_post_meta($af_donat_rule_, 'af_donat_enable_goal', true);

			$af_donat_goal_amot = get_post_meta($af_donat_rule_, 'af_donat_goal_amot', true);

			$af_donat_close_msg = get_post_meta($af_donat_rule_, 'af_donat_close_msg', true);

			$af_donatio_close = get_post_meta($af_donat_rule_, 'af_donatio_close', true);

			$af_donat_end_date = get_post_meta($af_donat_rule_, 'af_donat_end_date', true);

			$af_donat_end_type = get_post_meta($af_donat_rule_, 'af_donat_end_type', true);

			$af_no_of_days_donat = get_post_meta($af_donat_rule_, 'af_no_of_days_donat', true);

			$af_camp_goal_data = array(
				'goal_amount'      => $af_donat_goal_amot,
				'donat_end_date'   => $af_donat_end_date,
				'close_msg'        => $af_donat_close_msg,
				'end_goal_type'    => $af_donat_end_type,
				'no_donat_and_day' => $af_no_of_days_donat,
			);

			return $af_camp_goal_data;
		}

		public function close_donations_automatically() {

			$rule_ids = get_posts(
				array(
					'numberposts' => -1,
					'post_status' => 'any',
					'post_type'   => 'af_wc_donat',
					'orderby'     => 'ids',
					'order'       => 'DSC',
					'fields'      => 'ids',
					'meta_query'  => array(
						array(
							'key'     => 'af_donatio_close',
							'value'   => 'close',
							'compare' => '!=',
						),
					),
				)
			);

			foreach ( array_reverse( $rule_ids ) as $af_donat_rule_ ) {

				$af_donat_camp_goal_setting_optn = $this->af_donat_camp_goal_setting_optn($af_donat_rule_);

	
				$af_donat_enable_goal =  get_post_meta($af_donat_rule_, 'af_donat_enable_goal', true);

				if ( 'af_enab_goal' != $af_donat_enable_goal ) {
					continue;
				}

				if (in_array('amt_raisd', $af_donat_camp_goal_setting_optn)) {

					$af_donat_goal_amot    = get_post_meta($af_donat_rule_, 'af_donat_goal_amot', true);
					$product_id            = get_post_meta($af_donat_rule_, 'af_rule_as_prod', true);
					$donated_amount        = 0;
					$product_id            = get_post_meta($af_donat_rule_, 'af_rule_as_prod', true);
					$af_fee_amount_donated = get_post_meta($af_donat_rule_, 'af_donat_amt_on_camp_fee', true);


					$af_chk_dont_typ = get_post_meta($af_donat_rule_, 'af_donat_camp_t', true);

					$all_order = wc_get_orders(
						array(
							'type'   => 'shop_order',
							'limit'  => -1,
							'status' => array( 'processing', 'completed' ),
						)
					);

					if ('af_dona_fee_base' == $af_chk_dont_typ) {
						$donated_amount = $af_fee_amount_donated;
					} else {

						foreach ($all_order as $key => $af_order) {
							foreach ($af_order->get_items() as $key => $pro_item) {

								if ($product_id == $pro_item->get_product_id()) {
									$donated_amount += $pro_item->get_subtotal();
								}
							}
						}
					}

					if ( 'af_enab_goal' == $af_donat_enable_goal && $donated_amount >= $af_donat_goal_amot) {
						
						update_post_meta( $af_donat_rule_, 'af_donatio_close', 'close' );
						update_post_meta( $af_donat_rule_, 'af_donatio_close_date', gmdate('Y-m-d') );
					}

				} elseif (in_array('no_of_donat', $af_donat_camp_goal_setting_optn)) {

					$af_donat_number     = $af_donat_camp_goal_setting_optn['no_donat_and_day'];
					$af_no_of_days_donat = get_post_meta($af_donat_rule_, 'af_no_of_days_donat', true);
					$af_chk_dont_typ     = get_post_meta($af_donat_rule_, 'af_donat_camp_t', true);
					$af_check_fe_count   = get_post_meta($af_donat_rule_, 'af_donat_count_camp_fee', true);
					$donated_number      = 0;
					$product_id          = get_post_meta($af_donat_rule_, 'af_rule_as_prod', true);

					$all_order = wc_get_orders(
						array(
							'type'   => 'shop_order',
							'limit'  => -1,
							'status' => array( 'processing', 'completed' ),
						)
					);

					if ('af_dona_fee_base' == $af_chk_dont_typ) {
						$donated_number = $af_check_fe_count;
					} else {

						foreach ($all_order as $key => $af_order) {
							foreach ($af_order->get_items() as $key => $pro_item) {
								if ($product_id == $pro_item->get_product_id()) {
									++$donated_number;
								}
							}
						}
					}

					if ( 'af_enab_goal' == $af_donat_enable_goal && $donated_number >= $af_no_of_days_donat) {
						update_post_meta( $af_donat_rule_, 'af_donatio_close', 'close' );
						update_post_meta( $af_donat_rule_, 'af_donatio_close_date', gmdate('Y-m-d') );
					}

				} elseif (in_array('no_of_days', $af_donat_camp_goal_setting_optn)) {

					$af_no_of_days_donat = get_post_meta($af_donat_rule_, 'af_no_of_days_donat', true);
					$cur_date            = gmdate('Y-m-d');
					$rul_publ_date       = get_the_time('Y-m-d', $af_donat_rule_);
					$later               = new DateTime($cur_date);
					$earlier             = new DateTime($rul_publ_date);
					$check_no_days       = $earlier->diff($later)->format('%r%a');

					if ($check_no_days > $af_no_of_days_donat) {
						update_post_meta( $af_donat_rule_, 'af_donatio_close', 'close' );
						update_post_meta( $af_donat_rule_, 'af_donatio_close_date', gmdate('Y-m-d') );
					}

				} elseif (in_array('goal_end_date', $af_donat_camp_goal_setting_optn)) {

					if (!empty($af_donat_camp_goal_setting_optn['donat_end_date'])) {
						if (gmdate('Y-m-d') > $af_donat_camp_goal_setting_optn['donat_end_date']) {
							update_post_meta( $af_donat_rule_, 'af_donatio_close', 'close' );
							update_post_meta( $af_donat_rule_, 'af_donatio_close_date', gmdate('Y-m-d') );
						}
					}
					
				}
			}
		}

		public function af_donation_btn_chkout() {
			include_once AFWCD_PLUGIN_DIR . '/includes/class-af-wc-donation-front.php';
			$af_show_fee_amt = new AF_Wc_Donation_Front();

			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}
			$donate_cause = '';
			if (isset($_POST['rule_id'])) {
				$rule_id = sanitize_text_field($_POST['rule_id']);
			}
			if (isset($_POST['selected_amount'])) {
				$af_donat_amt = sanitize_text_field($_POST['selected_amount']);
			}

			if ( empty( $af_donat_amt ) && isset($_POST['af_other_input'] ) ) {
				$af_donat_amt = sanitize_text_field($_POST['af_other_input']);
			}

			if (isset($_POST['af_sub_period_interval'])) {
				$af_donat_time = sanitize_text_field($_POST['af_sub_period_interval']);
			}
			if (isset($_POST['af_sub_period'])) {
				$af_sub_period = sanitize_text_field($_POST['af_sub_period']);
			}
			if (isset($_POST['af_dont_lngt'])) {
				$af_dont_lngt = sanitize_text_field($_POST['af_dont_lngt']);
			}

			$donat_prod_name = get_the_title($rule_id);

			$donat_prod_id       = get_post_meta($rule_id, 'af_rule_as_prod', true);
			$af_donat_choice     = get_post_meta($rule_id, 'af_donat_choice', true);
			$af_donat_camp_t     = get_post_meta($rule_id, 'af_donat_camp_t', true);
			$af_fix_amount       = get_post_meta($rule_id, 'af_fix_amount', true);
			$af_donat_camp_fee_t = get_post_meta($rule_id, 'af_donat_camp_fee_t', true);
			$af_cart_slct_fee    = get_post_meta($rule_id, 'af_cart_slct_fee', true);

			$af_min_donat_amt = get_post_meta($rule_id, 'af_min_donat_amt', true);
			$af_max_donat_amt = get_post_meta($rule_id, 'af_max_donat_amt', true);

			if (isset($_POST['af_max'])) {
				$af_max_donat_amt = sanitize_text_field($_POST['af_max']);
			}
			if (isset($_POST['af_min'])) {
				$af_min_donat_amt = sanitize_text_field($_POST['af_min']);
			}

			$af_define_donat_choice = get_post_meta($rule_id, 'af_define_donat_choice', true);

			if ( 'af_dona_prod_base' == $af_donat_camp_t ) {

				if ('af_ena_recu' == $af_donat_choice) {


					if ( 'af_define_recu' == $af_define_donat_choice ) {
						$af_donat_amt  = get_post_meta( $rule_id, 'af_define_recu_price', true );
						$af_sub_period = get_post_meta( $rule_id, 'af_donat_period', true);
						$af_dont_lngt  = get_post_meta( $rule_id, 'af_donat_length', true);
						$af_donat_time = get_post_meta( $rule_id, 'af_donat_time', true);
					}

					$af_sub_interval_opt = array(
						'subscription_donation'        => $donat_prod_name,
						'donation_cause'               => $donate_cause,
						'donation_amount'              => $af_donat_amt,
						'subscription_period'          => $af_sub_period,
						'subscription_period_interval' => $af_donat_time,
						'subscription_length'          => $af_dont_lngt,
					);

					if (WC()->cart->add_to_cart($donat_prod_id, 1, 0, array(), $af_sub_interval_opt)) {

						if (!is_cart()) {
							$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
							$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

							wc_add_notice(esc_html__($notification_msg, 'af_donation') . '<a class="button wc-forward" href="' . esc_url(wc_get_cart_url()) . '">' . esc_html__('View cart', 'af_donation') . '  </a>', 'success');
						}
					}
				} else {
					if ($af_donat_amt < $af_min_donat_amt || $af_donat_amt > $af_max_donat_amt) {
						if (!is_cart()) {
							wc_add_notice(esc_html__('Please enter amount less then ' . $af_max_donat_amt . ' and greater then ' . $af_min_donat_amt, 'af_donation'), 'error');
							return;
						} else {
							wc_add_notice(esc_html__('Please enter amount less then ' . $af_max_donat_amt . ' and greater then ' . $af_min_donat_amt, 'af_donation'), 'error');
							return;
						}
					}

					if (WC()->cart->add_to_cart($donat_prod_id, 1, 0, array(), array(
						'donation'        => $donat_prod_name,
						'donation_cause'  => $af_donat_cause,
						'donation_amount' => $af_donat_amt,
					))) {

						if (!is_cart()) {
							$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
							$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

							wc_add_notice(esc_html__($notification_msg, 'af_donation') . '<a class="button wc-forward" href="' . esc_url(wc_get_cart_url()) . '">' . esc_html__('View cart', 'af_donation') . '  </a>', 'success');
						}
					}
				}

			} else {
				if ('af_round_fee' == $af_donat_camp_fee_t) {

					$af_donat_amt = $af_show_fee_amt->af_donat_round_of_calcu($rule_id);
				} else {
					$af_donat_amt = $af_fix_amount;
				}
				$donat_prod_name = get_the_title($rule_id);

				if ('af_perce' == $af_cart_slct_fee) {
					$af_per_number = get_post_meta($rule_id, 'af_amount_in_per', true);
					$af_total      = WC()->cart->get_subtotal();

					$af_donat_amt = ( $af_per_number / 100 ) * $af_total;
				} elseif ('af_fix' == $af_cart_slct_fee) {
					$af_donat_amt = get_post_meta($rule_id, 'af_fix_amount', true);
				}

				if (!empty(WC()->session->get('af_done_fee_in_cart'))) {
					$af_check_fee_in_sess   = (array) WC()->session->get('af_done_fee_in_cart');
					$af_check_fee_in_sess[] = array(
						'fee_name'    => $donat_prod_name,
						'fee_amount'  => $af_donat_amt,
						'rule_id_fee' => $rule_id,
					);
				} else {
					$af_check_fee_in_sess[] = array(
						'fee_name'    => $donat_prod_name,
						'fee_amount'  => $af_donat_amt,
						'rule_id_fee' => $rule_id,
					);
				}
				WC()->session->set('af_done_fee_in_cart', $af_check_fee_in_sess);
				if (!is_cart()) {
					$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
					$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

					wc_add_notice(esc_html__($notification_msg, 'af_donation') . '<a class="button wc-forward" href="' . esc_url(wc_get_cart_url()) . '">' . esc_html__('View cart', 'af_donation') . '  </a>', 'success');
				}
			}
		}

		public function af_donat_wc_mail2( $emails ) {
			include_once AFWCD_PLUGIN_DIR . 'includes/class-af-donat-wc-mail.php';
			$emails['af_donat_wc_mail'] = new af_donat_wc_mail();
			return $emails;
		}

		public function af_donat_add_to_card() {

			$donat_prod_name = '';
			$donat_prod_name = '';
			$donate_cause    = '';
			$af_donat_amt    = '';
			$af_sub_period   = '';
			$af_donat_time   = '';
			$af_dont_lngt    = '';
			$af_donat_amt    = 1;

			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}
			$af_donat_cause = '';

			if (!empty($_POST['af_donat_rule_id'])) {
				$post_id       = sanitize_text_field($_POST['af_donat_rule_id']);
				$donat_prod_id = get_post_meta($post_id, 'af_rule_as_prod', true);
				if (!empty($_POST['af_donat_amt'])) {
					$af_donat_amt = sanitize_text_field($_POST['af_donat_amt']);
				} else {
					$product_obj  = wc_get_product($donat_prod_id);
					$af_donat_amt = $product_obj->get_price();
				}

				$donat_prod_name = get_the_title($post_id);

				if (!empty($_POST['af_donat_cause'])) {
					$donate_cause = sanitize_text_field($_POST['af_donat_cause']);
				}
				if (!empty($_POST['subscription_period'])) {
					$af_sub_period = sanitize_text_field($_POST['subscription_period']);
				}
				if (!empty($_POST['subscription_period_interval'])) {
					$af_donat_time = sanitize_text_field($_POST['subscription_period_interval']);
				}
				if (!empty($_POST['subscription_length'])) {
					$af_dont_lngt = sanitize_text_field($_POST['subscription_length']);
				}

				$af_amt_type            = get_post_meta($post_id, 'af_amt_type', true);
				$af_min_donat_amt       = get_post_meta($post_id, 'af_min_donat_amt', true);
				$af_max_donat_amt       = get_post_meta($post_id, 'af_max_donat_amt', true);
				$af_define_donat_choice = get_post_meta($post_id, 'af_define_donat_choice', true);
				$af_donat_goal_amot     = get_post_meta($post_id, 'af_donat_goal_amot', true);
				$af_donat_enable_goal   = get_post_meta($post_id, 'af_donat_enable_goal', true);
				
				if ( 'custome_value' == $af_amt_type ) {

					if (!empty($af_max_donat_amt) && !empty($af_min_donat_amt)) {
						if ($af_donat_amt < $af_min_donat_amt || $af_donat_amt > $af_max_donat_amt) {
							if ('af_define_recu' != $af_define_donat_choice) {
								if (!is_cart()) {
									wc_add_notice(esc_html__('Please enter amount less then ' . $af_max_donat_amt . ' and greater then ' . $af_min_donat_amt, 'af_donation'), 'error');
									return;
								} else {
									wc_add_notice(esc_html__('Please enter amount less then ' . $af_max_donat_amt . ' and greater then ' . $af_min_donat_amt, 'af_donation'), 'error');
									return;
								}
							}
						}
					}

				} elseif ( 'pre_define' == $af_amt_type ) {

					if (!empty($af_donat_goal_amot) && 'af_enab_goal' == $af_donat_enable_goal ) {
						if ($af_donat_amt > $af_donat_goal_amot ) {
							if ('af_define_recu' != $af_define_donat_choice) {
								if (!is_cart()) {
									wc_add_notice(esc_html__('Please enter amount less then ' . $af_donat_goal_amot, 'af_donation'), 'error');
									return;
								} else {
									wc_add_notice(esc_html__('Please enter amount less then ' . $af_donat_goal_amot, 'af_donation'), 'error');
									return;
								}
							}
						}
					}

				}

				$af_define_donat_choice = get_post_meta($post_id, 'af_define_donat_choice', true);

				if ( 'af_define_recu' == $af_define_donat_choice ) {
					$af_donat_amt  = get_post_meta( $post_id, 'af_define_recu_price', true );
					$af_sub_period = get_post_meta( $post_id, 'af_donat_period', true);
					$af_dont_lngt  = get_post_meta( $post_id, 'af_donat_length', true);
					$af_donat_time = get_post_meta( $post_id, 'af_donat_time', true);
				}

				$af_sub_interval_opt = array(
					'subscription_donation'        => $donat_prod_name,
					'donation'                     => $donat_prod_name,
					'donation_cause'               => $donate_cause,
					'donation_amount'              => $af_donat_amt,
					'subscription_period'          => $af_sub_period,
					'subscription_period_interval' => $af_donat_time,
					'subscription_length'          => $af_dont_lngt,
				);

				if (WC()->cart->add_to_cart($donat_prod_id, 1, 0, array(), $af_sub_interval_opt)) {

					if (!is_cart()) {
						$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
						$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

						wc_add_notice(esc_html__($notification_msg, 'af_donation') . '<a class="button wc-forward" href="' . esc_url(wc_get_cart_url()) . '">' . esc_html__('View cart', 'af_donation') . '  </a>', 'success');
					}
				}
			}
		}

		public function af_donat_add_fee_in_cart() {
			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}
			if (WC()->cart->is_empty()) {
				WC()->session->set('af_done_fee_in_cart', '');
				return;
			}

			if (!empty($_POST['af_donat_rule_id'])) {
				$post_id = sanitize_text_field($_POST['af_donat_rule_id']);

				if (!empty(get_the_title($post_id))) {

					$donat_prod_name = get_the_title($post_id);
					$af_donat_amt    = isset($_POST['af_donat_amt']) ? sanitize_text_field($_POST['af_donat_amt']) : null;
					$af_donat_amt    = empty($af_donat_amt) ? get_post_meta($post_id, 'af_fix_amount', true) : $af_donat_amt;

					$af_fee_alre     = 'false';
					$af_fee_save_key = '';

					if (!empty(WC()->session->get('af_done_fee_in_cart'))) {
						$af_check_fee_in_sess = (array) WC()->session->get('af_done_fee_in_cart');
						foreach ($af_check_fee_in_sess as $key => $af_check_dublicate) {
							if ($post_id == $af_check_dublicate['rule_id_fee']) {
								$af_fee_alre     = 'true';
								$af_fee_save_key = $key;
							}
						}

						if ('true' == $af_fee_alre) {
							$af_check_fee_in_sess[ $af_fee_save_key ] = array(
								'fee_name'    => $donat_prod_name,
								'fee_amount'  => $af_donat_amt,
								'rule_id_fee' => $post_id,
							);
						} else {
							$af_check_fee_in_sess[] = array(
								'fee_name'    => $donat_prod_name,
								'fee_amount'  => $af_donat_amt,
								'rule_id_fee' => $post_id,
							);
						}
					} else {
						$af_check_fee_in_sess[] = array(
							'fee_name'    => $donat_prod_name,
							'fee_amount'  => $af_donat_amt,
							'rule_id_fee' => $post_id,
						);
					}

					WC()->session->set('af_done_fee_in_cart', $af_check_fee_in_sess);

					if (!is_cart()) {
						$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
						$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

						wc_add_notice(esc_html__($notification_msg, 'af_donation') . '<a class="button wc-forward" href="' . esc_url(wc_get_cart_url()) . '">' . esc_html__('View cart', 'af_donation') . '  </a>', 'success');
					} else {
						$af_noti_msg      =  get_option('af_donat_notify_msg_editor_id');
						$notification_msg = str_replace('{campaign_name}', $donat_prod_name, $af_noti_msg);

						wc_add_notice(esc_html__($notification_msg, 'af_donation'), 'success');
					}
				}
			}
		}

		public function af_donat_show_amt_optn_chkt() {

			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}
			$af_donat_rule_id = '';
			include_once AFWCD_PLUGIN_DIR . '/includes/class-af-wc-donation-front.php';

			$af_show_amt_optn = new AF_Wc_Donation_Front();
			?>
			<div class="af_refresh_opt">
			<?php

			if (!empty($_POST['af_donat_rule_id'])) {
				$af_donat_rule_id = sanitize_text_field($_POST['af_donat_rule_id']);
				$af_show_amt_optn->af_dont_disp_amt_optn_chkt($af_donat_rule_id);

				if (!empty($af_show_amt_optn) && 0 != $af_show_amt_optn) {
					return $af_show_amt_optn;
				}
			}
			?>
			</div>
			<?php
		}


		public function afwcd_create_post() {

			$labels1 = array(
				'name'                => esc_html__('Donation Campaigns', 'af_donation'),
				'singular_name'       => esc_html__('All Campaign', 'af_donation'),
				'add_new'             => esc_html__('Add New Campaign', 'af_donation'),
				'add_new_item'        => esc_html__('Add New Campaign', 'af_donation'),
				'edit_item'           => esc_html__('Edit Campaign', 'af_donation'),
				'new_item'            => esc_html__('New Campaign', 'af_donation'),
				'view_item'           => esc_html__('View Campaign', 'af_donation'),
				'search_items'        => esc_html__('Search Campaign', 'af_donation'),
				'exclude_from_search' => true,
				'all_items'           => esc_html__('Donations', 'af_donation'),
			);

			$args1 = array(
				'labels'             => $labels1,
				'menu_icon'          => plugins_url('assets/images/small_logo_grey.png', __FILE__),
				'public'             => false,
				'publicly_queryable' => false,
				'show_ui'            => true,
				'show_in_menu'       => 'woocommerce',
				'query_var'          => true,
				'capability_type'    => 'post',
				'has_archive'        => true,
				'hierarchical'       => false,
				'rewrite'            => array(
					'slug'       => 'af_wc_donat',
					'with_front' => false,
				),
				'supports'           => array( 'title', 'page-attributes', 'thumbnail' ),
			);

			register_post_type('af_wc_donat', $args1);

			if (empty(get_option('af_donat_notify_msg_editor_id'))) {
				update_option('af_donat_notify_msg_editor_id', 'Donation against {campaign_name} successfully added to cart.');
			}
		}


		public function af_donat_chart_update() {

			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}

			$af_wc_donat_rule = get_posts(
				array(
					'numberposts' => -1,
					'post_status' => 'publish',
					'post_type'   => 'af_wc_donat',
					'orderby'     => 'ids',
					'order'       => 'DSC',
					'fields'      => 'ids',
				)
			);

			$produt_as_rule  = array();
			$rules_titles    = array();
			$rule_data_array = array();
			$final_array     = array();
			$donated_amount  = 0;

			$selected_donation_rules = array();

			if (isset($_POST['selected_donation'])) {

				$selected_donation_rules = sanitize_meta('', $_POST['selected_donation'], '');
				$selected_donation       = $selected_donation_rules;

				foreach ($selected_donation as $key => $value) {
					$rules_titles[ $value ] = get_the_title($value);
				}

			} else {

				$selected_donation_rules = $af_wc_donat_rule;

				foreach ($af_wc_donat_rule as $af_rule_id ) {

					$rules_titles[ $af_rule_id ] = get_the_title($af_rule_id);
				}
			}

			$rule_data_array = array();
			$final_array[]   = array_merge(array( 'Dates' ), $rules_titles);

			$af_donat_strt = gmdate('Y') . '-1-1';
			$af_donat_end  = gmdate('Y-m-d');

			if (!empty($_POST['start_date'])) {
				$af_donat_strt = sanitize_text_field($_POST['start_date']);
			}

			if (!empty($_POST['end_date'])) {
				$af_donat_end = sanitize_text_field($_POST['end_date']);
			}

			$args = array(
				'type'         => 'shop_order',
				'status'       => array( 'processing', 'completed' ),
				'limit'        => -1,
				'date_created' => $af_donat_strt . '...' . $af_donat_end,
				'return'       => 'ids',
				'order'        => 'ASC',
				'orderby'      => 'date',
			);

			$order_ids = wc_get_orders($args);

			$af_donate_name = array();

			foreach ($order_ids as $order_id) {

				$order          =  wc_get_order($order_id);
				$order_date     = $order->get_date_created();
				$af_donate_date = strtotime($order_date->date('Y-m-d'));

				$af_zero_donation = 0;

				$af_donated_fee_array = get_post_meta($order->get_id(), 'af_donated_fee_array', true);

				if (!empty($af_donated_fee_array)) {

					foreach ($af_donated_fee_array as $key => $fee_data) {

						$fee_rule_id = $fee_data['rule_id_fee'];

						if ( in_array($fee_rule_id, $selected_donation_rules ) ) {

							$donated_amount = $fee_data['fee_amount'];

							if ( isset( $rule_data_array[ $af_donate_date ][ $fee_rule_id ] ) ) {
								$rule_data_array[ $af_donate_date ][ $fee_rule_id ] += floatval( $donated_amount );
							} else {
								$rule_data_array[ $af_donate_date ][ $fee_rule_id ] = floatval( $donated_amount );
							}
						}
					}
				}

				foreach ($order->get_items() as $key => $pro_item) {

					$af_donation_product_rule = get_post_meta($pro_item->get_product_id(), 'af_donation_product_rule', true);

					if ( in_array($af_donation_product_rule, $selected_donation_rules ) ) {
						
						$donated_amount = $pro_item->get_subtotal();

						if ( isset( $rule_data_array[ $af_donate_date ][ $af_donation_product_rule ] ) ) {
							$rule_data_array[ $af_donate_date ][ $af_donation_product_rule ] += $donated_amount;
						} else {
							$rule_data_array[ $af_donate_date ][ $af_donation_product_rule ] = $donated_amount;
						}
					}
				}
			}
			
			foreach ( $rule_data_array as $af_donate_date => $rules_values ) {

				$new_values = array();

				foreach ( $selected_donation_rules as $rule_id ) {

					$new_values[] = isset( $rules_values[ $rule_id ] ) ? floatval( $rules_values[ $rule_id ] ) : 0;
				}

				$date          = gmdate('F j, Y', $af_donate_date);
				$final_array[] = array_merge(array( $date ), $new_values);
			}

			wp_send_json(
				array(
					'chart_data' => $final_array,
				)
			);
		}

		public function af_wcd_global_constents_vars() {

			if (!defined('AFWCD_URL')) {
				define('AFWCD_URL', plugin_dir_url(__FILE__));
			}

			if (!defined('AFWCD_BASENAME')) {
				define('AFWCD_BASENAME', plugin_basename(__FILE__));
			}

			if (!defined('AFWCD_PLUGIN_DIR')) {
				define('AFWCD_PLUGIN_DIR', plugin_dir_path(__FILE__));
			}
		}
	}

		new AF_Wc_Donation_Main();
}
