<?php

/**
 * Define file.
 *
 * @package           WOOCP
 */
if (!defined('ABSPATH')) {
	die;
}
/**
 * Class start.
 *
 * @package           WOOCP
 */
if (!class_exists('AF_Wc_Donation_Admin')) {

	/**
	 * Admin class of Plugin
	 */

	class AF_Wc_Donation_Admin {



		public function __construct() {

			add_action('admin_menu', array( $this, 'af_wc_donation_setting' ));

			add_filter('woocommerce_get_settings_pages', array( $this, 'af_donat_add_seting_tab' ), 50);

			add_action('admin_head', array( $this, 'addCustomImportButton' ));

			add_action('add_meta_boxes', array( $this, 'af_wc_donate_metabox' ));

			add_action('save_post_af_wc_donat', array( $this, 'af_wc_donate_metabox_save_fields' ));

			add_action('admin_menu', array( $this, 'af_donat_create_submenu' ));

			add_action('admin_enqueue_scripts', array( $this, 'af_wc_add_assets_file' ));

			add_action('all_admin_notices', array( $this, 'render_tabs' ), 5);

			// conditionally remove duplicate submenu link
			add_action('admin_menu', array( $this, 'remove_submenu_link' ), 100);
		}

		public function remove_submenu_link() {
			global $pagenow, $typenow;

			if (( 'edit.php' === $pagenow && 'af_wc_donat' === $typenow )
				|| ( 'post.php' === $pagenow && isset($_GET['post']) && 'af_wc_donat' === get_post_type(sanitize_text_field($_GET['post'])) )
			) {
				remove_submenu_page('woocommerce', 'af_wc_donation');
			} elseif (( 'admin.php' === $pagenow && isset($_GET['page']) && 'af_wc_donation' === sanitize_text_field($_GET['page']) )) {

				remove_submenu_page('woocommerce', 'edit.php?post_type=af_wc_donat');
			} else {
				remove_submenu_page('woocommerce', 'edit.php?post_type=af_wc_donat');
			}
		}

		public function render_tabs() {
			global $post, $typenow;
			$screen = get_current_screen();

			// handle tabs on the relevant WooCommerce pages
			if ($screen && in_array($screen->id, $this->get_tab_screen_ids(), true)) {

				$tabs = apply_filters('af_donation_admin_tabs', array(
					'home'      => array(
						'title' => __('Home', 'af_donation'),
						'url'   => admin_url('admin.php?page=af_wc_donation'),
					),
					'campaigns' => array(
						'title' => __('Campaigns', 'af_donation'),
						'url'   => admin_url('edit.php?post_type=af_wc_donat'),
					),
				));

				if (is_array($tabs)) { ?>
					<div class="wrap woocommerce">
						<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">
							<?php
							$current_tab = $this->get_current_tab();

							foreach ($tabs as $id => $tab_data) {
								$class = $id === $current_tab ? array( 'nav-tab', 'nav-tab-active' ) : array( 'nav-tab' );
								printf('<a href="%1$s" class="%2$s">%3$s</a>', esc_url($tab_data['url']), implode(' ', array_map('sanitize_html_class', $class)), esc_html($tab_data['title']));
							}
							?>
						</h2>
					</div>
					<?php
				}
			}
		}

		public function get_current_tab() {
			$screen = get_current_screen();

			switch ($screen->id) {
				case 'af_wc_donat':
				case 'edit-af_wc_donat':
					return 'campaigns';
				case 'woocommerce_page_af_wc_donation':
					return 'home';
			}
		}

		public function get_tab_screen_ids() {
			$tabs_screens = array(
				'af_wc_donat',
				'edit-af_wc_donat',
				'woocommerce_page_af_wc_donation',
			);

			return $tabs_screens;
		}

		public function af_wc_add_assets_file() {

			wp_enqueue_style('af_wc_donate_metabox_css', AFWCD_URL . 'assets/css/af_wc_donate_metabox_css.css', false, '1.0.0', false);

			wp_enqueue_script('custom_af_dona_select_js', plugins_url('../assets/js/select2.js', __FILE__), array( 'jquery' ), '1.0.0', true);

			wp_enqueue_script('custom_af_dona_incld_select_js', plugins_url('../assets/js/af_add_select.js', __FILE__), array( 'jquery' ), '1.0.0', true);

			wp_enqueue_script('custom_af_dona_gen_set_js', plugins_url('../assets/js/af_dona_gen_set_js.js', __FILE__), array( 'jquery' ), '1.0.0', true);

			wp_enqueue_script('custom_af_dona_metabox_js', plugins_url('../assets/js/af_wc_donate_metabox_js.js', __FILE__), array( 'jquery' ), '1.0.0', true);

			wp_enqueue_style('custom_af_dona_select2_css', plugins_url('../assets/css/select2.css', __FILE__), false, '1.0', false);


			wp_enqueue_script('af_dona_graph_js', plugins_url('../assets/js/af_dona_graph_js.js', __FILE__), array( 'jquery' ), '1.0.0', true);

			wp_localize_script(
				'af_dona_graph_js',
				'af_donat_var',
				array(
					'admin_url' => admin_url('admin-ajax.php'),
					'nonce'     => wp_create_nonce('af_donat_nonce'),
				)
			);

			wp_enqueue_style('af_donate_font', 'https://fonts.googleapis.com/css2?family=Poppins:wght@200;300;400;600;700&display=swap', false, '1.0', false);

			wp_enqueue_style('af_donate_font_aw', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', false, '1.0', false);

			wp_enqueue_script('af_donat_graph', 'https://www.gstatic.com/charts/loader.js', array( 'jquery' ), '0.5', true);
		}

		public function af_wc_donate_metabox() {

			add_meta_box(
				'af_wc_donat_goal',
				esc_html__('Campaign Goal', 'af_donation'),
				array( $this, 'af_wc_donat_goal_calback' ),
				'af_wc_donat'
			);

			add_meta_box(
				'af_wc_donat',
				esc_html__('Campaign Settings', 'af_donation'),
				array( $this, 'af_wc_donate_metabox_calback' ),
				'af_wc_donat'
			);

			add_meta_box(
				'af_wc_donat_cause',
				esc_html__('Donation Cause', 'af_donation'),
				array( $this, 'af_wc_donate_cause_metabox_calback' ),
				'af_wc_donat'
			);

			add_meta_box(
				'af_wc_donat_Recurring',
				esc_html__('Recurring Donation', 'af_donation'),
				array( $this, 'af_wc_donate_recurring_metabox_calback' ),
				'af_wc_donat'
			);

			add_meta_box(
				'af_donat_camp_loca',
				esc_html__('Select Location', 'af_donation'),
				array( $this, 'af_donat_camp_loca_metabox_calback' ),
				'af_wc_donat'
			);
		}

		public function af_wc_donate_metabox_calback() {

			include AFWCD_PLUGIN_DIR . 'includes/metaboxes/af_wc_donation_metabox.php';
		}

		public function af_wc_donat_goal_calback() {

			include AFWCD_PLUGIN_DIR . 'includes/metaboxes/af_wc_donation_goal_metabox.php';
		}

		public function af_wc_donate_cause_metabox_calback() {

			include AFWCD_PLUGIN_DIR . 'includes/metaboxes/af_wc_donation_cause_metabox.php';
		}

		public function af_wc_donate_recurring_metabox_calback() {

			include AFWCD_PLUGIN_DIR . 'includes/metaboxes/af_wc_donation_recurring_metabox.php';
		}

		public function af_donat_camp_loca_metabox_calback() {

			include AFWCD_PLUGIN_DIR . 'includes/metaboxes/af_donat_camp_loca_metabox.php';
		}

		public function af_wc_donate_metabox_save_fields( $post_id ) {
			$donat_prod_price       = 1;
			$af_prod_data_virtual   = '';
			$af_prod_data_dwnlod    = '';
			$check_sub_enab         = '';
			$af_define_recu_price   = 1;
			$af_define_donat_choice = '';

			if (isset($_POST['af_donat_nonce'])) {
				$nonce = sanitize_text_field(wp_unslash($_POST['af_donat_nonce']));
				if (!wp_verify_nonce($nonce, '_wpnonce')) {

					die('Failed security check!');
				}
			}
			if (isset($_POST['af_amt_type'])) {

				$af_amt_type =  sanitize_text_field($_POST['af_amt_type']);

				update_post_meta($post_id, 'af_amt_type', $af_amt_type);
			}

			if (isset($_POST['af_amt_opt_type'])) {

				$af_amt_opt_type =  sanitize_text_field($_POST['af_amt_opt_type']);

				update_post_meta($post_id, 'af_amt_opt_type', $af_amt_opt_type);
			} else {
				update_post_meta($post_id, 'af_amt_opt_type', '');
			}
			// cause field
			// recurring
			// donation choice
			if (isset($_POST['af_donat_choice'])) {

				$af_donat_choice =  sanitize_text_field($_POST['af_donat_choice']);

				update_post_meta($post_id, 'af_donat_choice', $af_donat_choice);
			}

			if (isset($_POST['af_donatio_close'])) {

				$af_donat_choice =  sanitize_text_field($_POST['af_donatio_close']);

				update_post_meta($post_id, 'af_donatio_close', $af_donat_choice);
				update_post_meta($post_id, 'af_donatio_close_date', gmdate('Y-m-d'));
			} else {
				update_post_meta($post_id, 'af_donatio_close', '');
			}

			//donation time
			if (isset($_POST['af_donat_time'])) {

				$af_donat_time =  sanitize_text_field($_POST['af_donat_time']);

				update_post_meta($post_id, 'af_donat_time', $af_donat_time);
			}
			// donation period
			if (isset($_POST['af_donat_period'])) {

				$af_donat_period =  sanitize_text_field($_POST['af_donat_period']);

				update_post_meta($post_id, 'af_donat_period', $af_donat_period);
			}
			// donation length
			if (isset($_POST['af_donat_length'])) {

				$af_donat_length =  sanitize_text_field($_POST['af_donat_length']);

				update_post_meta($post_id, 'af_donat_length', $af_donat_length);
			}
			// donation goal fields

			if (!empty($_POST['af_donat_enable_goal'])) {

				$af_donat_enable_goal =  sanitize_text_field($_POST['af_donat_enable_goal']);

				update_post_meta($post_id, 'af_donat_enable_goal', $af_donat_enable_goal);
			} else {
				update_post_meta($post_id, 'af_donat_enable_goal', 'af_enab_goal');
			}

			if (isset($_POST['af_donat_goal_amot'])) {

				$af_donat_goal_amot =  sanitize_text_field($_POST['af_donat_goal_amot']);

				if (!empty($af_donat_goal_amot)) {
					update_post_meta($post_id, 'af_donat_goal_amot', $af_donat_goal_amot);
				} else {
					$af_donat_goal_amot = 1000;
					update_post_meta($post_id, 'af_donat_goal_amot', $af_donat_goal_amot);
				}
			}


			if (isset($_POST['af_wc_goal_type_name'])) {

				$af_wc_goal_type_name =  sanitize_text_field($_POST['af_wc_goal_type_name']);

				update_post_meta($post_id, 'af_wc_goal_type_name', $af_wc_goal_type_name);
			}

			if (isset($_POST['af_no_of_days_donat'])) {

				$af_no_of_days_donat =  sanitize_text_field($_POST['af_no_of_days_donat']);

				update_post_meta($post_id, 'af_no_of_days_donat', $af_no_of_days_donat);
			}

			if (isset($_POST['af_donat_end_date'])) {

				$af_donat_end_date =  sanitize_text_field($_POST['af_donat_end_date']);

				update_post_meta($post_id, 'af_donat_end_date', $af_donat_end_date);
			}

			if (isset($_POST['af_donat_close_msg'])) {

				$af_donat_close_msg =  sanitize_text_field($_POST['af_donat_close_msg']);

				update_post_meta($post_id, 'af_donat_close_msg', $af_donat_close_msg);
			}

			if (isset($_POST['af_slct_disp_typ_bar'])) {

				$af_slct_disp_typ_bar =  sanitize_text_field($_POST['af_slct_disp_typ_bar']);

				update_post_meta($post_id, 'af_slct_disp_typ_bar', $af_slct_disp_typ_bar);
			}

			//end

			if (isset($_POST['af_donat_end_type'])) {

				$af_donat_end_type =  sanitize_text_field($_POST['af_donat_end_type']);

				update_post_meta($post_id, 'af_donat_end_type', $af_donat_end_type);
			}

			// donation campaign setting fields

			if (isset($_POST['af_donat_camp_t'])) {

				$af_donat_camp_t =  sanitize_text_field($_POST['af_donat_camp_t']);

				update_post_meta($post_id, 'af_donat_camp_t', $af_donat_camp_t);
			}

			if (isset($_POST['af_donat_camp_fee_t'])) {

				$af_donat_camp_fee_t =  sanitize_text_field($_POST['af_donat_camp_fee_t']);

				update_post_meta($post_id, 'af_donat_camp_fee_t', $af_donat_camp_fee_t);
			}

			if (isset($_POST['af_min_donat_amt'])) {

				$af_min_donat_amt =  sanitize_text_field($_POST['af_min_donat_amt']);
				if (!empty($af_min_donat_amt)) {
					$donat_prod_price = $af_min_donat_amt;
				}

				update_post_meta($post_id, 'af_min_donat_amt', $af_min_donat_amt);
			}

			if (isset($_POST['af_max_donat_amt'])) {

				$af_max_donat_amt =  sanitize_text_field($_POST['af_max_donat_amt']);

				update_post_meta($post_id, 'af_max_donat_amt', $af_max_donat_amt);
			}


			if (isset($_POST['get_table_count'])) {

				$get_table_count =  sanitize_text_field($_POST['get_table_count']);

				if (!empty($_POST['af_get_rem_count'])) {
					$get_table_count_rema =  sanitize_text_field($_POST['af_get_rem_count']);
					$get_table_count      = explode(',', $get_table_count_rema);
					update_post_meta($post_id, 'get_table_count', $get_table_count);
					foreach ($get_table_count as $key => $value) {

						if (!empty($_POST[ 'af_donat_number' . $value ])) {
							$af_dona_no = sanitize_text_field($_POST[ 'af_donat_number' . $value ]);
							update_post_meta($post_id, 'af_donat_number' . $value, $af_dona_no);
						}
						if (!empty($_POST[ 'af_donat_text' . $value ])) {
							$af_donat_txt = sanitize_text_field($_POST[ 'af_donat_text' . $value ]);
							update_post_meta($post_id, 'af_donat_text' . $value, $af_donat_txt);
						}
					}
				} else {
					update_post_meta($post_id, 'get_table_count', $get_table_count);
					for ($value = 1; $value <= $get_table_count; $value++) {

						if (!empty($_POST[ 'af_donat_number' . $value ])) {
							$af_dona_no = sanitize_text_field($_POST[ 'af_donat_number' . $value ]);
							update_post_meta($post_id, 'af_donat_number' . $value, $af_dona_no);
						}
						if (!empty($_POST[ 'af_donat_text' . $value ])) {
							$af_donat_txt = sanitize_text_field($_POST[ 'af_donat_text' . $value ]);
							update_post_meta($post_id, 'af_donat_text' . $value, $af_donat_txt);
						}
					}
				}
			}

			if (isset($_POST['af_cart_slct_fee'])) {

				$af_cart_slct_fee =  sanitize_text_field($_POST['af_cart_slct_fee']);

				update_post_meta($post_id, 'af_cart_slct_fee', $af_cart_slct_fee);
			}

			if (isset($_POST['af_amount_in_per'])) {

				$af_amount_in_per =  sanitize_text_field($_POST['af_amount_in_per']);

				update_post_meta($post_id, 'af_amount_in_per', $af_amount_in_per);
			}

			if (isset($_POST['af_fix_amount'])) {

				$af_fix_amount =  sanitize_text_field($_POST['af_fix_amount']);

				update_post_meta($post_id, 'af_fix_amount', $af_fix_amount);
			}

			if (isset($_POST['af_donat_fee_msg'])) {

				$af_donat_fee_msg =  sanitize_text_field($_POST['af_donat_fee_msg']);

				update_post_meta($post_id, 'af_donat_fee_msg', $af_donat_fee_msg);
			}

			if (isset($_POST['af_donat_round_off_mul'])) {

				$af_donat_round_off_mul =  sanitize_text_field($_POST['af_donat_round_off_mul']);

				update_post_meta($post_id, 'af_donat_round_off_mul', $af_donat_round_off_mul);
			}

			if (isset($_POST['af_round_off_msg'])) {

				$af_round_off_msg =  sanitize_text_field($_POST['af_round_off_msg']);

				update_post_meta($post_id, 'af_round_off_msg', $af_round_off_msg);
			}

			if (isset($_POST['af_enble_other_optn'])) {

				$af_enble_other_optn =  sanitize_text_field($_POST['af_enble_other_optn']);

				update_post_meta($post_id, 'af_enble_other_optn', $af_enble_other_optn);
			} else {
				update_post_meta($post_id, 'af_enble_other_optn', '');
			}

			if (isset($_POST['af_show_other_optn'])) {

				$af_show_other_optn =  sanitize_text_field($_POST['af_show_other_optn']);

				update_post_meta($post_id, 'af_show_other_optn', $af_show_other_optn);
			}
			// donation cause setting fields

			if (isset($_POST['af_don_compaign_causes'])) {

				$af_don_compaign_causes = sanitize_meta('', $_POST['af_don_compaign_causes'], '');
				update_post_meta( $post_id, 'af_don_compaign_causes', $af_don_compaign_causes );
			} else {
				update_post_meta( $post_id, 'af_don_compaign_causes', array() );
			}


			if (isset($_POST['af_donat_choice'])) {

				$af_donat_choice =  sanitize_text_field($_POST['af_donat_choice']);

				update_post_meta($post_id, 'af_donat_choice', $af_donat_choice);
			}

			if (isset($_POST['af_define_donat_choice'])) {

				$af_define_donat_choice =  sanitize_text_field($_POST['af_define_donat_choice']);

				update_post_meta($post_id, 'af_define_donat_choice', $af_define_donat_choice);
			}

			if (isset($_POST['af_admin_recu_lnght'])) {

				$af_admin_recu_lnght =  sanitize_text_field($_POST['af_admin_recu_lnght']);

				update_post_meta($post_id, 'af_admin_recu_lnght', $af_admin_recu_lnght);
			}

			if (isset($_POST['af_define_recu_price'])) {

				$af_define_donat_choice =  sanitize_text_field($_POST['af_define_recu_price']);
				if ('af_ena_recu' == $af_donat_choice) {
					if ('af_define_recu' == $af_define_donat_choice) {
						$donat_prod_price =  sanitize_text_field($_POST['af_define_recu_price']);
						if (empty($af_define_donat_choice)) {
							update_post_meta($post_id, 'af_define_recu_price', 1000);
						}
					}
				}


				update_post_meta($post_id, 'af_define_recu_price', $af_define_donat_choice);
			}

			if (isset($_POST['af_chkout_loc'])) {

				$af_chkout_loc =  sanitize_text_field($_POST['af_chkout_loc']);

				update_post_meta($post_id, 'af_chkout_loc', $af_chkout_loc);
			} else {
				update_post_meta($post_id, 'af_chkout_loc', '');
			}

			if (isset($_POST['af_cart_loc'])) {

				$af_cart_loc =  sanitize_text_field($_POST['af_cart_loc']);

				update_post_meta($post_id, 'af_cart_loc', $af_cart_loc);
			} else {
				update_post_meta($post_id, 'af_cart_loc', '');
			}

			if (isset($_POST['af_prod_data_virtual'])) {

				$af_prod_data_virtual =  sanitize_text_field($_POST['af_prod_data_virtual']);

				update_post_meta($post_id, 'af_prod_data_virtual', $af_prod_data_virtual);
			} else {
				update_post_meta($post_id, 'af_prod_data_virtual', '');
			}

			if (isset($_POST['af_prod_data_dwnlod'])) {

				$af_prod_data_dwnlod =  sanitize_text_field($_POST['af_prod_data_dwnlod']);

				update_post_meta($post_id, 'af_prod_data_dwnlod', $af_prod_data_dwnlod);
			} else {
				update_post_meta($post_id, 'af_prod_data_dwnlod', '');
			}

			remove_action('save_post', array( $this, 'af_wc_donate_metabox_save_fields' ));
			if (!empty($_POST['af_donat_number1'])) {
				if ($donat_prod_price > $_POST['af_donat_number1']) {
					$donat_prod_price = sanitize_text_field($_POST['af_donat_number1']);
				} elseif ($af_min_donat_amt > $_POST['af_donat_number1']) {
					$donat_prod_price = sanitize_text_field($_POST['af_donat_number1']);
				} elseif (1 == $donat_prod_price) {
					$donat_prod_price = sanitize_text_field($_POST['af_donat_number1']);
				}
			}

			if (isset($_POST['af_min_donat_amt'])) {
				if (isset($_POST['af_donat_camp_t'])) {
					if (!empty(get_the_title())) {
						if ('af_dona_prod_base' == $_POST['af_donat_camp_t']) {
							if (empty($donat_prod_price)) {
								$donat_prod_price = 1;
							}

							$af_rule_as_prod = get_post_meta($post_id, 'af_rule_as_prod', true);


							$af_if_Prod_exist = wc_get_product($af_rule_as_prod);

							if (empty($af_if_Prod_exist)) {

								$post_thumbnail_id =  get_post_thumbnail_id($post_id);

								$post_idd = wp_insert_post(array(
									'post_title'    => get_the_title(),
									'post_content'  => '',
									'post_status'   => 'publish',
									'post_parent'   => '',
									'post_type'     => 'product',
									'_thumbnail_id' => $post_thumbnail_id,
								));

								if (isset($_POST['af_donat_choice'])) {
									$check_sub_enab = sanitize_text_field($_POST['af_donat_choice']);
									if ('af_ena_recu' == $check_sub_enab) {

										wp_set_object_terms($post_idd, 'subscription', 'product_type', false);

										$af_interval = get_post_meta($post_id, 'af_donat_time', true);
										$af_period   = get_post_meta($post_id, 'af_donat_period', true);
										$af_length   = get_post_meta($post_id, 'af_admin_recu_lnght', true);

										update_post_meta($post_idd, 'af_donation_product_rule', $post_id);

										update_post_meta($post_idd, '_subscription_period', $af_period);
										update_post_meta($post_idd, '_subscription_period_interval', $af_interval);
										update_post_meta($post_idd, '_subscription_length', $af_length);

										if (empty($donat_prod_price) || 0 == $donat_prod_price) {
											$donat_prod_price = 1;
										}

										if ('af_define_recu' == $_POST['af_define_donat_choice']) {
											if (!empty($_POST['af_define_recu_price'])) {
												$donat_prod_price =  sanitize_text_field($_POST['af_define_recu_price']);
											}
										}

										update_post_meta($post_idd, '_price', $donat_prod_price);
										update_post_meta($post_idd, '_regular_price', $donat_prod_price);
										update_post_meta($post_idd, '_subscription_price', $donat_prod_price);
									} else {
										wp_set_object_terms($post_idd, 'simple', 'product_type');
									}
								}

								if ('af_define_recu' == $_POST['af_define_donat_choice']) {
									if (!empty($_POST['af_define_recu_price'])) {
										$donat_prod_price =  sanitize_text_field($_POST['af_define_recu_price']);
									}
								}

								update_post_meta($post_idd, 'af_donation_product', 'Donation Product');
								update_post_meta($post_idd, 'af_donation_product_rule', $post_id);
								update_post_meta($post_id, 'af_rule_as_prod', $post_idd);

								update_post_meta($post_idd, '_price', $donat_prod_price);
								update_post_meta($post_idd, '_regular_price', $donat_prod_price);

								update_post_meta($post_idd, '_visibility', 'visible');
								update_post_meta($post_idd, '_stock_status', 'instock');
								update_post_meta($post_idd, 'total_sales', '');

								update_post_meta($post_idd, '_downloadable', $af_prod_data_dwnlod);
								update_post_meta($post_idd, '_virtual', $af_prod_data_virtual);

								update_post_meta($post_idd, '_sale_price', '');
								update_post_meta($post_idd, '_purchase_note', '');
								update_post_meta($post_idd, '_featured', '');
								update_post_meta($post_idd, '_weight', '');
								update_post_meta($post_idd, '_length', '');
								update_post_meta($post_idd, '_width', '');
								update_post_meta($post_idd, '_height', '');
								update_post_meta($post_idd, '_sku', '');

								update_post_meta($post_idd, '_sold_individually', '');
								update_post_meta($post_idd, '_manage_stock', 'no');
								update_post_meta($post_idd, '_backorders', 'no');
								update_post_meta($post_idd, '_stock', '');

								wp_safe_redirect(admin_url('/post.php?post=' . $post_idd . '&action=edit'));
								exit;
							} else {
								if (isset($_POST['af_donat_choice'])) {
									$check_sub_enab = sanitize_text_field($_POST['af_donat_choice']);
								}

								if ('af_ena_recu' == $check_sub_enab) {


									$post      = get_post($af_rule_as_prod);
									$new_title = mb_convert_case(get_the_title(), MB_CASE_TITLE, 'UTF-8');
									// if $new_title is defined, but it matches the current title, return

									$prod_id = get_post_meta($post_id, 'af_rule_as_prod', true);


									$post_update = array(
										'ID'         => $prod_id,
										'post_title' => $new_title,
									);
									update_post_meta($prod_id, 'af_donation_product_rule', $post_id);
									$af_interval       = get_post_meta($post_id, 'af_donat_time', true);
									$af_period         = get_post_meta($post_id, 'af_donat_period', true);
									$af_length         = get_post_meta($post_id, 'af_admin_recu_lnght', true);
									$post_thumbnail_id =  get_post_thumbnail_id($post_id);

									set_post_thumbnail($prod_id, $post_thumbnail_id);

									if (empty($donat_prod_price) || 0 == $donat_prod_price) {
										$donat_prod_price = 1;
									}

									if ('af_define_recu' == $_POST['af_define_donat_choice']) {

										if (!empty($_POST['af_define_recu_price'])) {
											$donat_prod_price =  sanitize_text_field($_POST['af_define_recu_price']);
										}
									}


									update_post_meta($prod_id, '_subscription_price', $donat_prod_price);
									update_post_meta($prod_id, '_subscription_period', $af_period);
									update_post_meta($prod_id, '_subscription_period_interval', $af_interval);
									update_post_meta($prod_id, '_subscription_length', $af_length);

									update_post_meta($prod_id, '_price', $donat_prod_price);
									update_post_meta($prod_id, '_regular_price', $donat_prod_price);
								} else {

									$post = get_post($af_rule_as_prod);
									// ensure title case of $new_title

									$new_title = mb_convert_case(get_the_title(), MB_CASE_TITLE, 'UTF-8');
									// if $new_title is defined, but it matches the current title, return

									$prod_id = get_post_meta($post_id, 'af_rule_as_prod', true);

									$post_update     = array(
										'ID'         => $prod_id,
										'post_title' => $new_title,
									);
									$attributes_data = array();



									$post_thumbnail_id =  get_post_thumbnail_id($post_id);

									set_post_thumbnail($prod_id, $post_thumbnail_id);

									update_post_meta($prod_id, '_downloadable', $af_prod_data_dwnlod);
									update_post_meta($prod_id, '_virtual', $af_prod_data_virtual);
									// 
									if ('af_define_recu' == $af_define_donat_choice) {
										if (!empty($_POST['af_define_recu_price'])) {
											$donat_prod_price =  sanitize_text_field($_POST['af_define_recu_price']);
										}
									}
									update_post_meta($prod_id, '_price', $donat_prod_price);
									update_post_meta($prod_id, '_regular_price', $donat_prod_price);
									update_post_meta($prod_id, '_manage_stock', 'no');
									wp_update_post($post_update);
								}
							}
						}
					}
				}
			}
		}

		public function addCustomImportButton() {
			global $current_screen;
			global $pagenow;
			// Not our post type, exit earlier
			// You can remove this if condition if you don't have any specific post type to restrict to. 
			if ('af_wc_donat' != $current_screen->post_type) {
				return;
			} else {
				$af_dashboard_url = get_admin_url() . 'admin.php?page=af_wc_donation';

				?>
				<span id="af_dasbord_btn">
					<?php
					if ('post-new.php' === $pagenow) {
						return;
					}
					?>
					<a href="<?php echo esc_url($af_dashboard_url); ?>" class=" af_dasbord_btn" style=""><?php echo esc_html__('Dashboard', 'af_donation'); ?></a>
				</span>
				<?php
			}
		}


		public function af_wc_donation_setting() {
			add_submenu_page(
				'edit.php?post_type=af_wc_donat', // define post type.
				'Dashboard setting', // Page title.
				esc_html__('Dashboard', 'af_donation '), // Title.
				'manage_options', // Capability.
				'af_donation_Dashboard', // slug.                  // short code reference
				array( $this, 'af_wc_dona_dashboard_submenu_callback' ),   // callback
				0

			);
			add_submenu_page(
				'edit.php?post_type=af_wc_donat', // define post type.
				'General setting', // Page title.
				esc_html__('Setting', 'af_donation '), // Title.
				'manage_options', // Capability.
				'af_wc_donation_setting', // slug.                  // short code reference
				array( $this, 'af_wc_donation_submenu_callback' )   // callback
			);
		}


		public function af_donat_add_seting_tab( $settings ) {

			$settings[] = include AFWCD_PLUGIN_DIR . '/includes/class-af-add-section.php';
			return $settings;
		}


		public function af_wc_dona_dashboard_submenu_callback() {
		}

		public function af_donat_create_submenu() {
			add_submenu_page(
				'woocommerce', // parent slug.
				'Donation', // Page title.
				esc_html__('Donations', 'af_donation '), // Title.
				'manage_options', // Capability.
				'af_wc_donation', // slug.
				array( $this, 'af_donat_create_submenu_callback' )
				// Callback.
			);
		}

		public function af_donat_create_submenu_callback() {
			$admin_url       = admin_url();
			$custom_post_url = '/edit.php?post_type=af_wc_donat';
			global $active_tab;

			if (isset($_GET['tab'])) {
				$active_tab = sanitize_text_field(wp_unslash($_GET['tab']));
			} else {
				$active_tab = 'af_donat_dashboard';
			}
			?>
			<div class="wrap">
				<?php settings_errors(); ?>
				<h2><?php esc_html_e('Dashboard', 'af_donation'); ?></h2>
				<?php
				// General Setting Tab.
				if ('donation_rule' === $active_tab) {
					wp_safe_redirect($admin_url . $custom_post_url);
					exit;
				}

				if ('af_donat_dashboard' === $active_tab) {
					$chek_sect_page = 'true';
					?>

					<input type="hidden" name="chek_sect_page" class="chek_sect_page" value="<?php echo esc_attr($chek_sect_page); ?>">
					<?php

					$this->af_donat_dashboard_lbl_style();

					settings_fields('af_donat_dashboard_field');

					do_settings_sections('af_donat_dashboard_page');

					$this->af_donat_dashboard_single_chart();
				}
				?>
			</div>
			<?php
		}

		public function af_donat_dashboard_single_chart() {
			$af_wc_donat_rule = get_posts(
				array(
					'numberposts' => -1,
					'post_status' => 'publish',
					'post_type'   => 'af_wc_donat',
					'orderby'     => 'ids',
					'order'       => 'DSC',

				)
			);
			if (empty($af_wc_donat_rule)) {
				return;
			}
			?>
			<table class="af_all_camp_tble_admin">
				<tr>
					<th><?php echo esc_html__('Campaign Name', 'af_donation'); ?></th>
					<th><?php echo esc_html__('Target', 'af_donation'); ?></th>
					<th><?php echo esc_html__('Recurring', 'af_donation'); ?></th>
					<th><?php echo esc_html__('Closing date', 'af_donation'); ?></th>
				</tr>

				<?php
				foreach ($af_wc_donat_rule as $key => $value) {
					$af_camp_target    = get_post_meta($value->ID, 'af_donat_goal_amot', true);
					$af_donat_end_date = get_post_meta($value->ID, 'af_donat_end_date', true);
					$af_donat_end_type = get_post_meta($value->ID, 'af_donat_end_type', true);
					$af_donat_choice   = get_post_meta($value->ID, 'af_donat_choice', true);
					$af_donat_camp_t   = get_post_meta($value->ID, 'af_donat_camp_t', true);
					$af_donat_end_date = get_post_meta($value->ID, 'af_donat_end_date', true);
					?>
					<tr>
						<th><?php echo esc_html__(get_the_title($value->ID), 'af_donation'); ?></th>
						<td>
							<?php
							if (!empty($af_camp_target)) {
								echo wp_kses_post(wc_price($af_camp_target));
							}
							?>
						</td>
						<td>
							<?php
							if ('af_ena_recu' == $af_donat_choice && 'af_dona_prod_base' == $af_donat_camp_t) {
								echo esc_html__('True', 'af_donation');
							} else {
								echo esc_html__('False', 'af_donation');
							}
							?>

						</td>
						<td>
							<?php

							if ('goal_end_date' == $af_donat_end_type && !empty($af_donat_end_date)) {
								echo esc_html__($af_donat_end_date, 'af_donation');
							}
							?>

						</td>
					</tr>
					<?php
				}
				?>
			</table>
			<?php
		}

		public function af_donat_dashboard_lbl_style() {
			$af_donated_price_save    = 0;
			$af_total_donat_amount    = 0;
			$af_donated_price         = 0;
			$af_active_camp_donat     = 0;
			$af_donation_product_rule = 0;
			$af_rule_ids              = array();
			$prod_id_aga_rule         = array();
			$af_donate_name           = array();

			$af_wc_donat_rule = get_posts(
				array(
					'numberposts' => -1,
					'post_status' => 'publish',
					'post_type'   => 'af_wc_donat',
					'fields'      => 'ids',

				)
			);
			foreach ($af_wc_donat_rule as $key => $value_id) {

				$prod_id_aga_rule[] = get_post_meta($value_id, 'af_rule_as_prod', true);
			}

			$af_donat_strt = gmdate('Y') . '-1-1';
			$af_donat_end  = gmdate('Y-m-d');

			$args      = array(
				'status'       => array( 'processing', 'completed' ),
				'limit'        => -1,
				'date_created' => $af_donat_strt . '...' . $af_donat_end,
				'return'       => 'ids',
				'order'        => 'ASC',
				'orderby'      => 'date',
			);
			$all_order = wc_get_orders($args);

			foreach ($all_order as $order_id) {

				$order = wc_get_order($order_id);

				if (!$order) {
					continue;
				}

				$order_date     = $order->get_date_created();
				$af_donate_date = strtotime($order_date->date('Y-m-d'));

				foreach ($order->get_items() as $key => $pro_item) {

					$af_donation_product_rule = get_post_meta($pro_item->get_product_id(), 'af_donation_product_rule', true);

					if (in_array($af_donation_product_rule, $af_wc_donat_rule)) {

						$af_enable_goal    =  get_post_meta($af_donation_product_rule, 'af_donat_enable_goal', true);
						$check_donat_close = get_post_meta($af_donation_product_rule, 'af_donatio_close', true);

						if ('close' != $check_donat_close) {

							$af_active_camp_donat += $pro_item->get_subtotal();
						}

						$af_total_donat_amount += $pro_item->get_subtotal();

						if (in_array($af_donate_date, array_keys($af_donate_name))) {

							$af_donate_name[ $af_donate_date ][1] += $pro_item->get_subtotal();
						} else {

							$af_donate_name[ $af_donate_date ] = array( $order_date->date('F j,Y'), $pro_item->get_subtotal() );
						}
					}
				}

				$af_donated_price_arr = get_post_meta($order->get_id(), 'af_donated_fee_array', true);

				if (!empty($af_donated_price_arr)) {

					foreach ($af_donated_price_arr as $key => $get_amt_value) {

						if (!empty($get_amt_value['rule_id_fee']) && in_array($get_amt_value['rule_id_fee'], $af_wc_donat_rule)) {

							$_rule_id   = $get_amt_value['rule_id_fee'];
							$fee_amount = floatval($get_amt_value['fee_amount']);

							$af_enable_goal =  get_post_meta($_rule_id, 'af_donat_enable_goal', true);

							if ('af_enab_goal' == $af_enable_goal) {
								$af_active_camp_donat += floatval($af_donated_price_save);
							}

							if (in_array($af_donate_date, array_keys($af_donate_name))) {

								$af_donate_name[ $af_donate_date ][1] += floatval( $fee_amount );
								
							} else {

								$af_donate_name[ $af_donate_date ] = array( $order_date->date('F j,Y'), floatval($fee_amount) );
							}

							$af_total_donat_amount += floatval($fee_amount);
						}
					}
				}
			}

			$total_donation = $af_total_donat_amount;
			?>
			<input type="hidden" class="af_check_dashboard">
			<div class="af_dashboard_lbl">
				<div class="af_dashboard_lbl_left">
					<h3><?php echo esc_html__('Total Donation Amount', 'af_donation'); ?></h3>
					<p><?php echo wp_kses_post(wc_price($total_donation)); ?></p>
				</div>
			</div>
			<br>
			<?php

			$this->af_donat_dashboard_table_style($af_donate_name);
		}

		public function af_donat_dashboard_table_style( $donation_data ) {

			$start_date = gmdate('Y') . '-01-01';
			$end_date   = gmdate('Y-m-d');
			?>
			<input type="hidden" class="check_is_dashboard" value="true">
			<div class="af_donat_dashboard_main">
				<div class="af_donat_dashboard_opt_main">
					<div class="af_donat_dashboard_opt_left">
						<h3><?php echo esc_html__('Select Donation', 'af_donation'); ?>:</h3>
						<div class="af_donat_dash_slct">
							<?php
							$af_wc_donat_rule_id = get_posts(
								array(
									'numberposts' => -1,
									'post_status' => 'publish',
									'post_type'   => 'af_wc_donat',
									'orderby'     => 'ids',
									'order'       => 'DSC',
									'fields'      => 'ids',
								)
							);
							?>
							<select class="af_select_donat_dashboard" style="width: 250px;" multiple>
								<?php

								foreach ($af_wc_donat_rule_id as $key => $af_rule_id_select) {
									?>
									<option value="<?php echo esc_attr($af_rule_id_select); ?>">
										<?php echo esc_html__(get_the_title($af_rule_id_select), 'af_donation'); ?>
									</option>
									<?php
								}

								?>
							</select>
						</div>
					</div>
					<div class="af_donat_dashboard_opt_right">
						<h3 class="af_date_h"><?php echo esc_html__('Choose Date', 'af_donation'); ?>:</h3 class="af_date_h">
						<div class="af_donat_field">
							<label><?php echo esc_html__('Start', 'af_donation'); ?></label><input type="date" name="" class="af_donat_strt_date" value="<?php echo esc_attr($start_date); ?>">
							<label><?php echo esc_html__('End', 'af_donation'); ?></label><input type="date" name="" class="af_donat_end_date" value="<?php echo esc_attr($end_date); ?>">
							<div class="af_dashb_filter_btn">
								<button class="button af_donat_filter_btn" id="af_donat_filter_date">
									<?php echo esc_html__('Filter', 'af_donation'); ?> </button>
							</div>
						</div>

					</div>
				</div>
				<div id="linechart_material" style="height: 450px"></div>
			</div>
			<?php

			$af_donate_cart_data =  array( array( 'Dates', 'Total Donation' ) );

			if (!empty($donation_data)) {

				foreach ($donation_data as $key => $af_names) {

					$af_donate_cart_data[] = array( $af_names[0], floatval($af_names[1]) );
				}

			} else {
				$af_donate_cart_data[] = array( gmdate('Y-m-d'), 0 );
			}

			?>
			<script type="text/javascript">
				var af_donate_cart_data = <?php echo wp_json_encode($af_donate_cart_data); ?>;
			</script>

			<?php
		}
	}

	new AF_Wc_Donation_Admin();
}
