<?php

/**
 * Constructor of membership activated.
 */
if (!defined('ABSPATH')) {
	die;
}
class Af_Thank_For_Donation extends WC_Email {

	public function __construct() {
		$this->id             = 'Af_Thank_For_Donation';
		$this->title          = __('Addify Donation Thankyou', 'af_donation');
		$this->customer_email = true;
		$this->description    = __('This email will be send to customer Thankyou for donation.', 'af_donation');
		$this->template_base  = AFWCD_PLUGIN_DIR;
		$this->template_html  = 'template/email/email-sm-html-template.php';
		$this->template_plain =  'template/email/plain/email-sm-plain-template.php';
		$this->placeholders   = array(
			'{Product_name}'  => '',
			'{product_price}' => '',
		);
		parent::__construct();
		add_action('Af_Thank_For_Donation', array( $this, 'trigger' ), 10, 1);
	}

	public function get_default_subject() {
		return __('Thanks for donation', 'af_donation');
	}

	public function get_default_heading() {
		return __('Heading', 'af_donation');
	}

	public function trigger( $af_donat_mail_info ) {
		$this->setup_locale();
		if (!empty($af_donat_mail_info)) {

			foreach ($af_donat_mail_info as $key => $af_info) {
				if (!empty($af_info['cust_email'])) {
					$cust_email = $af_info['cust_email'];
				}
			}
			$this->placeholders['{Product_name}']  = '';
			$this->placeholders['{product_price}'] = '';
			$this->af_donat_mail_info              = $af_donat_mail_info;

			if (!empty($cust_email)) {
				$this->recipient = $cust_email;
			}



			if ($this->is_enabled() && $this->get_recipient()) {
				$this->send($this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments());
			}
		}
		$this->restore_locale();
	}
	public function get_content_html() {

		return wc_get_template_html(
			$this->template_html,
			array(
				'registration'       => $this->object,
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => false,
				'name'               => $this->af_donat_mail_info,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
		);
	}

	public function get_content_plain() {
		return wc_get_template_html(
			$this->template_plain,
			array(
				'registration'       => $this->object,
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => false,
				'plain_text'         => false,
				'email'              => $this,
			),
			$this->template_base,
			$this->template_base
		);
	}
	// form fields that are displayed in WooCommerce->Settings->Emails
	public function init_form_fields() {
		$abc               = esc_attr__('<code>' . esc_html(implode('</code>, <code>', array_keys($this->placeholders))) . '</code>');
		$placeholder_text  = sprintf(esc_attr__('Available placeholders: ' . $abc));
		$this->form_fields = array(
			'enabled'            => array(
				'title'   => __('Enable/Disable', 'af_donation'),
				'type'    => 'checkbox',
				'label'   => __('Enable this email notification', 'af_donation'),
				'default' => 'yes',
			),

			'subject'            => array(
				'title'       => __('Subject', 'af_donation'),
				'type'        => 'text',
				'desc_tip'    => true,
				'description' => $placeholder_text,
				'placeholder' => $this->get_default_subject(),
				'default'     => '',
			),
			'additional_content' => array(
				'title'       => __('Additional content', 'af_donation'),
				'description' => __('Text to appear below the main email content.', 'af_donation') . ' ' . $placeholder_text,
				'css'         => 'width:400px; height: 75px;',
				'placeholder' => __('N/A', 'af_donation'),
				'type'        => 'textarea',
				'default'     => $this->get_default_additional_content(),
				'desc_tip'    => true,
			),
			'heading'            => array(
				'title'       => __('Email heading', 'af_donation'),
				'type'        => 'text',
				'desc_tip'    => true,
				'description' => $placeholder_text,
				'placeholder' => $this->get_default_heading(),
				'default'     => '',
			),
			'email_type'         => array(
				'title'       => __('Email type', 'af_donation'),
				'type'        => 'select',
				'description' => __('Choose which format of email to send.', 'af_donation'),
				'default'     => 'html',
				'class'       => 'email_type wc-enhanced-select',
				'options'     => $this->get_email_type_options(),
				'desc_tip'    => true,
			),
		);
	}
}
